@@ -12,10 +12,10 @@ using LineSearch: LiFukushimaLineSearch
 using MaybeInplace: @bb
 using NonlinearSolveBase: NonlinearSolveBase, ImmutableNonlinearProblem, L2_NORM,
                           nonlinearsolve_forwarddiff_solve, nonlinearsolve_dual_solution,
-                          AbstractNonlinearSolveAlgorithm
+                          AbstractNonlinearSolveAlgorithm, NonlinearVerbosity, @SciMLMessage,
+                          AbstractVerbosityPreset
 using SciMLBase: SciMLBase, NonlinearFunction, NonlinearProblem,
                  NonlinearLeastSquaresProblem, ReturnCode, remake
-
 using LinearAlgebra: LinearAlgebra, dot
 
 using StaticArraysCore: StaticArray, SArray, SVector, MArray
